<?php
/** 
 * Author: Thomas GILBERT <thomas.gilbert@ryxeo.com>
 * Date: 2011
 * Version: 1.0
 * @licence Affero GPL 3
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU Affero General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Affero General Public License for more details.
 *
 *   You should have received a copy of the GNU Affero General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class myUser extends sfGuardSecurityUser
{
  public function getIdCalendrier() {
    $nId = $this->getId();
    $oCalendar = Doctrine::getTable('tbl_calendrier')->findOneBy('id_user', $nId);    
    if (!$oCalendar) {
        $oCalendar = new tbl_calendrier();
        $oCalendar->setIdUser($nId);
        $oCalendar->save();
    }
    return $oCalendar->getId();
  }
  public function getId() {
    return  $this->getGuardUser()->getId();
  }
  public function getDomaine() {
    return  $this->getGuardUser()->getIdDomaine();
  }
  public function getGroupeClasse() {
    $oGroupUsers = $this->getGuardUser()->getTblGroupe();
    $aGroupe = array();
    foreach ($oGroupUsers as $oGroupUser) {
        if (!in_array($oGroupUser->getId(), $aGroupe)) {
          $aGroupe[] = $oGroupUser->getId();
        }
    }
    return $aGroupe;
  }
  public function getGroupeClasseLib() {
    $oGroupUsers = $this->getGuardUser()->getTblGroupe();
    $aGroupe = array();
    foreach ($oGroupUsers as $oGroupUser) {
        if (!in_array($oGroupUser->getTitre(), $aGroupe)) {
          $aGroupe[] = $oGroupUser->getTitre();
        }
    }
    return $aGroupe;
  }  
  public function getEnfants() {
    $oUser = $this->getGuardUser();
    $nUser = $oUser->getId();
    $oGroupeUsers = Doctrine::getTable('tbl_groupe')->getListGroupByRespEnfant($nUser);
    $oGroupeUsers = $oGroupeUsers->execute();
    $aUsername = array();
    foreach ($oGroupeUsers as $oGroupeUser) {
        $sTitre = $oGroupeUser->getTitre();
        $nLenResp = strlen(sfConfig::get('app_prefixe_resp_legal'));
        $aUsername[] = substr($sTitre, $nLenResp);
    }
    if (empty($aUsername)) {
        return null;
    }
    $oEnfants = Doctrine::getTable('sfGuardUser')->findBySql('username in ? and id_domaine = ?', array($aUsername, $oUser->getIdDomaine()), Doctrine_Core::HYDRATE_RECORD);
    return $oEnfants;
  }
  public function getCahierTexteRespLegal() {
      $oEnfants = $this->getEnfants();
      if ($oEnfants != null) {
          $aEnfants = array();
          foreach ($oEnfants as $oEnfant) {
              $aEnfants[] = $oEnfant->getId();
              $oCahier = Doctrine::getTable('tbl_cahier_texte')->findOneBy('id_user', $oEnfant->getId());
              if (!$oCahier) {
                  moncahiertexteActions::createCahier($oEnfant);
              }
          }
          $oCahier = Doctrine::getTable('tbl_cahier_texte')->findBySql('id_user in ?', array($aEnfants), Doctrine_Core::HYDRATE_RECORD);
          return $oCahier;
      }
      return null;
  }
  public function isAuthorisationCahier($psUsername, $pnIdDomaine) {
      $bDroit = false;
      if ($this->hasPermission('admin')) {
          $bDroit = true;
      } elseif ($this->hasGroup('enseignants')) {
        $oUser = $this->getGuardUser();
        if ($oUser->getIdDomaine() == $pnIdDomaine) {
          $oUserEleve = Doctrine::getTable('sfGuardUser')->findBySql('username = ? and id_domaine = ?', array($psUsername, $pnIdDomaine), Doctrine_Core::HYDRATE_RECORD);
          if ($oUserEleve) {
           $oGroupe = Doctrine::getTable('tbl_groupeuser')->findOneBy('id_sfguarduser', $oUserEleve[0]->getId());
           $nGroupe = $oGroupe->getIdGroupe();
           $aGroupeEnseignant = $this->getGroupeClasse();
           if (in_array($nGroupe, $aGroupeEnseignant)) {
               $bDroit = true;
           }
          }
        }
      } elseif ($this->hasGroup('responsable-legal')) {
        if ($this->getDomaine() == $pnIdDomaine) {
            if (Doctrine::getTable('tbl_groupeuser')->authoriseRespEleve($psUsername, $this->getId())) {
                $bDroit = true;
            }
        }
      } elseif ($this->hasPermission('admin_domaine')) {
        if ($this->getDomaine() == $pnIdDomaine) $bDroit = true;
      } elseif ($this->hasGroup('eleves')) {
        if ($this->getUsername() == $psUsername && $this->getDomaine() == $pnIdDomaine) $bDroit = true;
      }
      return $bDroit;
  }
  public function isAuthorisationCahierTexteGroupe($pnIdCahier) {
      $bDroit = false;
       if ($this->hasPermission('admin')) {
          $bDroit = true;
      } elseif ($this->hasPermission('admin_domaine')) {
          $oUser = $this->getGuardUser();
          $oQuery = Doctrine::getTable('tbl_cahier_texte')->createQuery('c');
          $oQuery->leftJoin('c.tbl_groupe g');
          $oQuery->where('c.id = ?', $pnIdCahier);
          $oQuery->andWhere('g.id_domaine = ?', $oUser->getIdDomaine());
          $oQuery->execute();
          if ($oQuery->count() > 0) {
              $bDroit = true;
          }
      } elseif ($this->hasGroup('enseignants')) {
          $oUser = $this->getGuardUser();
          $oCahier = Doctrine::getTable('tbl_cahier_texte')->find($pnIdCahier);
          $nGroupe = $oCahier->getIdGroupe();
          $oGroupe = Doctrine::getTable('tbl_groupeuser')->findBySql('id_groupe = ? and id_sfguarduser = ?', array($nGroupe, $oUser->getId()), Doctrine_Core::HYDRATE_RECORD);
          if ($oGroupe->count() > 0) {
              $bDroit = true;
          }
      }
      return $bDroit;
  }
  public function getCahierLiaisonRespLegal() {
      $nUser = $this->getId();
      $oEnfants = $this->getEnfants();
      if ($oEnfants != null) {
          $aEnfants = array();
          foreach ($oEnfants as $oEnfant) {
              $aEnfants[] = $oEnfant->getId();
              $oCahier = Doctrine::getTable('tbl_cahier_liaison')->findOneBy('id_user', $oEnfant->getId());
              if (!$oCahier) {
                  $oCahier = moncahierliaisonActions::createCahier($oEnfant);
              }
              $oResp = Doctrine::getTable('tbl_responsable_liaison')->findBySql('id_user = ? and id_cahier_liaison = ?', array($nUser, $oCahier->getId()), Doctrine_Core::HYDRATE_RECORD);
              if ($oResp->count() == 0) {
                  moncahierliaisonActions::addResponsableLiaison($nUser, $oCahier->getId());
              }
          }
          $oCahier = Doctrine::getTable('tbl_cahier_liaison')->findBySql('id_user in ?', array($aEnfants), Doctrine_Core::HYDRATE_RECORD);
          return $oCahier;
      }
      return null;
  }
  public function getCahierLiaisonAdmin() {
      $query = Doctrine::getTable('sfGuardUser')->createQuery('c');
  }
  public function getCahierLiaisonListArray() {
      if ($this->hasGroup('responsable-legal')) {
          $oCahiers = $this->getCahierLiaisonRespLegal();
      } elseif ($this->hasCredential('resp_groupe') || $this->hasGroup('admin domaine')) {
          $oEleves = Doctrine::getTable('sfGuardUser')->getListEleves()->execute();
          foreach ($oEleves as $oEleve) {
              $aEleve[] = $oEleve->getId();
          }
          $oCahiers = Doctrine::getTable('tbl_cahier_liaison')->findBySql('id_user in ?', array($aEleve));                    
      }
      $aCahier = array();
      foreach ($oCahiers as $oCahier) {
          $aCahier[] = $oCahier->getId();
      }
      return $aCahier;
  }
}
