<?php
/** 
 * Author: Thomas GILBERT <thomas.gilbert@ryxeo.com>
 * Date: 2011
 * Version: 1.0
 * @licence Affero GPL 3
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU Affero General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Affero General Public License for more details.
 *
 *   You should have received a copy of the GNU Affero General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class devoirsActions extends sfActions
{
  public function executeIndex(sfWebRequest $request)
  {
    $this->tbl_devoirs = Doctrine_Core::getTable('tbl_devoir')
      ->createQuery('a')
      ->execute();
  }
  public function executeNew(sfWebRequest $request)
  {
      if ($this->checkAutorisation($request)) {
        $nIdCahier = $request->getParameter('id_cahier');
        if ($request->hasParameter('jour')) {
          $this->sJour = $request->getParameter('jour');
          $oJour = Doctrine::getTable('tbl_jours')->findOneBy('lib', $this->sJour);
        }
        $this->form = new devoirEleveForm(array(), array('id_cahier' => $nIdCahier, 'jour' => isset($oJour)?$oJour->getId():'lundi'));
      } else {
        $this->redirect('@cahier_texte');
      }
  }
  public function executeCreate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod(sfRequest::POST));
    $this->form = new devoirEleveForm();
    $this->processForm($request, $this->form);
    $this->setTemplate('new');
  }
  public function executeEdit(sfWebRequest $request)
  {
    if ($this->checkAutorisation($request)) {
      $this->forward404Unless($tbl_devoir = Doctrine_Core::getTable('tbl_devoir')->find(array($request->getParameter('id'))), sprintf('Object tbl_devoir does not exist (%s).', $request->getParameter('id')));
      if ($request->hasParameter('jour')) {
        $this->sJour = $request->getParameter('jour');
      }
      $this->form = new devoirEleveForm($tbl_devoir);
    } else {
        $this->redirect('@cahier_texte');
    }
  }
  public function executeUpdate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod(sfRequest::POST) || $request->isMethod(sfRequest::PUT));
    $this->forward404Unless($tbl_devoir = Doctrine_Core::getTable('tbl_devoir')->find(array($request->getParameter('id'))), sprintf('Object tbl_devoir does not exist (%s).', $request->getParameter('id')));
    $this->form = new devoirEleveForm($tbl_devoir);
    $this->processForm($request, $this->form);
    $this->setTemplate('edit');
  }
  public function executeDelete(sfWebRequest $request)
  {
     if ($this->checkAutorisation($request)) {
        $this->forward404Unless($tbl_devoir = Doctrine_Core::getTable('tbl_devoir')->find(array($request->getParameter('id'))), sprintf('Object tbl_devoir does not exist (%s).', $request->getParameter('id')));
        $tbl_devoir->delete();
     }
     if ($request->hasParameter('jour')) {
        $this->sJour = $request->getParameter('jour');
        $this->redirect('@cahier_texte?jour='.$this->sJour);
     }
     $this->redirect('@cahier_texte');
  }
  protected function processForm(sfWebRequest $request, sfForm $form)
  {
    $form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
    if ($form->isValid())
    {
      $tbl_devoir = $form->save();
      $oJour = $tbl_devoir->getTblJours();
      $this->redirect('@cahier_texte?jour='.$oJour->getLib());      
    }
  }
  private function checkAutorisation(sfWebRequest $request) {
      $bAutorisation = false;
      if ($request->hasParameter('id_cahier')) {
        $nIdCahier = $request->getParameter('id_cahier');
        $oCahier = Doctrine::getTable('tbl_cahier_texte')->find($nIdCahier);
        $oUser = $oCahier->getSfGuardUser();
        if ($oUser->getUsername() != '') {
          if ($this->getUser()->isAuthorisationCahier($oUser->getUsername(), $oUser->getIdDomaine())) {
            $bAutorisation = true;
         }
        } else {
          if ($this->getUser()->isAuthorisationCahierTexteGroupe($nIdCahier)) {
            $bAutorisation = true;
          }
        }
     }
     return $bAutorisation;
  }
  public function executeTerminer(sfWebRequest $request) {
     if ($this->checkAutorisation($request)) {
        $this->forward404Unless($tbl_devoir = Doctrine_Core::getTable('tbl_devoir')->find(array($request->getParameter('id'))), sprintf('Object tbl_devoir does not exist (%s).', $request->getParameter('id')));
        $oJour = $tbl_devoir->getTblJours();
        $tbl_devoir->setIsClosed($request->getParameter('terminer'));
        $tbl_devoir->save();
        $this->redirect('@cahier_texte?jour='.$oJour->getLib());
     }
     $this->redirect('@cahier_texte');
  }
}
