<?php
/** 
 * Author: Thomas GILBERT <thomas.gilbert@ryxeo.com>
 * Date: 2011
 * Version: 1.0
 * @licence Affero GPL 3
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU Affero General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Affero General Public License for more details.
 *
 *   You should have received a copy of the GNU Affero General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class sfGuardUserTable extends PluginsfGuardUserTable
{
    public static function getInstance()
    {
        return Doctrine_Core::getTable('sfGuardUser');
    }
  public function retrieveByUsernameAdmin($username, $isActive = true, $isSuperAdmin = true)
  {
    $query = Doctrine_Core::getTable('sfGuardUser')->createQuery('u')
      ->where('u.username = ?', $username)
      ->addWhere('u.is_active = ?', $isActive)
      ->addWhere('u.is_super_admin = ?', $isSuperAdmin)
    ;
    return $query->fetchOne();
  }
  public function retrieveByUsernameDomaine($username, $nDomaine, $isActive = true)
  {
    $query = Doctrine_Core::getTable('sfGuardUser')->createQuery('u')
      ->where('u.username = ?', $username)
      ->addWhere('u.is_active = ?', $isActive)
      ->addWhere('u.id_domaine = ?', $nDomaine)
    ;
    return $query->fetchOne();
  }
  public function getListUser() {
      $oUser = sfContext::getInstance()->getUser();
      $query = $this->createQuery('u');
      $nDomaine =  $oUser->getDomaine();
      if ($oUser->hasCredential('admin')) {
      } elseif ($oUser->hasCredential('admin_domaine')) {
        $query->where('u.id_domaine = ?', $nDomaine);
      }
      $query->execute();
      return $query;
  }
  public function findUser($pnIdDomaine) {
        $q = $this->createQuery('u');
        $q->addWhere('u.id_domaine = ?', $pnIdDomaine);
        $oUsers = $q->execute();
        $aUser = array();
        foreach ($oUsers as $oUser) {
          $aUser[] = $oUser->getId();
        }
        return $aUser;
  }
  public function findElevesByGroupeClasse($paGroupe) {
      $oGroupeEleve = Doctrine::getTable('sfGuardGroup')->findOneBy('name', sfConfig::get('app_groupe_eleve'));
      $oQuery = $this->createQuery('u');
      $oQuery->leftJoin('u.sfGuardUserGroup ug');
      $oQuery->andWhere('ug.group_id = ?', $oGroupeEleve->getId());
      $oQuery->leftJoin('u.tbl_groupeuser gu');
      $oQuery->andWhereIn('gu.id_groupe', $paGroupe);
      return $oQuery;
  }
  public function findResp($poUser) {
      $oQuery = $this->createQuery('u');
      $oQuery->leftJoin('u.tbl_groupeuser gu');
      $oQuery->leftJoin('gu.tbl_groupe g');
      $oQuery->andWhere('g.id_domaine = ?', $poUser->getIdDomaine());
      $oQuery->andWhere('g.titre = ?', sfConfig::get('app_prefixe_resp_legal').$poUser->getUsername());
      return $oQuery;
  }
  public function findUserNoCahier($pnGroupeEleve, $pnDomaine, $psTypeCahier) {
      $q = new Doctrine_Query();
      $q->select('c.id_user')->from($psTypeCahier.' c');
      $q->where('c.id_user is not null');
      $oQuery = $this->createQuery('u');
      $oQuery->leftJoin('u.sfGuardUserGroup ug');
      $oQuery->andWhere('ug.group_id=?', $pnGroupeEleve);
      $oQuery->andWhere('u.id_domaine=?', $pnDomaine);
      $oQuery->andWhere('u.id NOT IN ('.$q.')');
      return $oQuery;
  }
  public function findUserCahier($pnGroupeEleve, $pnDomaine, $psTypeCahier) {
      $q = new Doctrine_Query();
      $q->select('c.id_user')->from($psTypeCahier.' c');
      $q->where('c.id_user is not null');
      $oQuery = $this->createQuery('u');
      $oQuery->leftJoin('u.sfGuardUserGroup ug');
      $oQuery->andWhere('ug.group_id=?', $pnGroupeEleve);
      $oQuery->andWhere('u.id_domaine=?', $pnDomaine);
      $oQuery->andWhere('u.id IN ('.$q.')');
      return $oQuery;
  }
  public function findRespsGroup($pnIdGroupEnseignant, $pnIdGroup) {
      $q = new Doctrine_Query();
      $q->select('c.user_id')->from('sfGuardUserGroup c');
      $q->where('c.group_id='.$pnIdGroupEnseignant);
      $oQuery = $this->createQuery('u');
      $oQuery->leftJoin('u.tbl_groupeuser gu');
      $oQuery->andWhere('gu.id_groupe=?', $pnIdGroup);
      $oQuery->andWhere('u.id IN ('.$q.')');
      return $oQuery;
  }
  public function getListEleves() {      
      $oUser = sfContext::getInstance()->getUser();
      $query = $this->createQuery('u');
      $nDomaine =  $oUser->getDomaine();
      $oGroupEleves = Doctrine::getTable('sfGuardGroup')->findOneBy('name', 'eleves');
      if ($oUser->hasCredential('admin')) {
      } elseif ($oUser->hasCredential('admin_domaine')) {
        $query->where('u.id_domaine = ?', $nDomaine);
        $query->leftJoin('u.sfGuardUserGroup ug');
        $query->andWhere('ug.group_id ='.$oGroupEleves->getId());
      } elseif ($oUser->hasCredential('resp_groupe')) {
        $aGroups =  $oUser->getGroupeClasse();
        $query->where('u.id_domaine = ?', $nDomaine);
        $query->leftJoin('u.sfGuardUserGroup ug');
        $query->andWhere('ug.group_id ='.$oGroupEleves->getId());
        $query->leftJoin('u.tbl_groupeuser g');
        $query->andWhereIn('g.id_groupe', $aGroups);
      }      
      return $query;    
  }
}